<?php

declare(strict_types=1);

namespace LinkMobility\ShopwareSmsApiPlugin\Controller;

use League\OAuth2\Client\Provider\GenericProvider;
use LinkMobility\ShopwareSmsApiPlugin\Factory\GenericProviderFactory;
use LinkMobility\ShopwareSmsApiPlugin\Service\TokenCacheAdapter;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

#[Route(defaults: ['_routeScope' => ['api']])]
class AuthorizationController extends AbstractController
{
    private GenericProvider $provider;

    public function __construct(
        GenericProviderFactory $factory,
        private RequestStack $requestStack,
        private TokenCacheAdapter $tokenCacheAdapter,
        ) {
        $this->provider = $factory->create();
    }

    #[Route(
        '/api/_action/link-mobility-shopware-sms-api-plugin/authorize',
        name: 'api.action.link-mobility-shopware-sms-api-plugin-authorize',
        methods: ['GET']
    )]
    public function authorize(): Response
    {
        $authorizationUrl = $this->provider->getAuthorizationUrl([
            'scope' => [
                'sms',
                'contacts',
                'blacklist',
            ], ]);

        $session = $this->requestStack->getSession();
        $session->set('oauth2pkceCode', $this->provider->getPkceCode());

        return new JsonResponse(['redirectUrl' => $authorizationUrl]);
    }

    #[Route(
        '/api/_action/link-mobility-shopware-sms-api-plugin/access',
        name: 'api.action.link-mobility-shopware-sms-api-plugin-access',
        methods: ['GET'],
        defaults: ['auth_required' => false]
    )]
    public function getAccessToken(Request $request): Response
    {
        $session = $this->requestStack->getSession();
        $this->provider->setPkceCode($session->get('oauth2pkceCode'));

        $accessToken = $this->provider->getAccessToken('authorization_code', [
            'code' => $request->query->get('code'),
        ]);

        $this->tokenCacheAdapter->save($accessToken);

        return new RedirectResponse('/admin#/linkMobility/smsApi/index');
    }
}
