<?php

declare(strict_types=1);

namespace LinkMobility\ShopwareSmsApiPlugin\Controller;

use Shopware\Core\Framework\DataAbstractionLayer\EntityRepository;
use Shopware\Core\System\SalesChannel\SalesChannelContext;
use Shopware\Storefront\Controller\StorefrontController;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Session\Flash\FlashBag;
use Symfony\Component\Routing\Annotation\Route;

/**
 * @Route(defaults={"_routeScope"={"storefront"}})
 */
class BackInStockReminderController extends StorefrontController
{
    public function __construct(
        private FlashBag $flashBag,
        private EntityRepository $reminderRepository
    ) {
    }

    /**
     * @Route("/link_mobility_shopware_sms_api_plugin_back_in_stock_notify", name="link-mobility-shopware-sms-api-plugin.back_in_stock.register", methods={"POST"})
     */
    public function registerForNotification(Request $request, SalesChannelContext $context): RedirectResponse
    {
        $body = $request->request->all();
        $validationError = false;

        $consent = $request->request->getBoolean('consent');
        if (!$consent) {
            $this->flashBag->add('danger', $this->trans('link-mobility-shopware-sms-api-plugin.consentRequired'));
            $validationError = true;
        }

        $phoneNumber = $body['phoneNumber'] ?? '';

        if (9 > strlen($phoneNumber)) {
            $this->flashBag->add('danger', $this->trans('link-mobility-shopware-sms-api-plugin.phoneNumberInvalid'));
            $validationError = true;
        }

        $id = $body['id'] ?? null;
        if (null === $id) {
            $this->flashBag->add('danger', $this->trans('link-mobility-shopware-sms-api-plugin.productIdRequired'));

            return $this->redirectToRoute('frontend.home.page');
        }

        if (!$validationError) {
            $this->reminderRepository->upsert([[
                'productId' => $id,
                'phoneNumber' => $phoneNumber,
            ]], $context->getContext());

            $this->flashBag->add('success', $this->trans('link-mobility-shopware-sms-api-plugin.registrationSuccessful'));
        }

        return $this->redirectToRoute('frontend.detail.page', ['productId' => $body['id']]);
    }
}
