<?php

declare(strict_types=1);

namespace LinkMobility\ShopwareSmsApiPlugin\Controller;

use Shopware\Core\Content\Product\SalesChannel\FindVariant\AbstractFindProductVariantRoute;
use Shopware\Core\Content\Product\SalesChannel\Review\AbstractProductReviewSaveRoute;
use Shopware\Core\Content\Seo\SeoUrlPlaceholderHandlerInterface;
use Shopware\Core\Framework\Feature;
use Shopware\Core\System\SalesChannel\SalesChannelContext;
use Shopware\Core\System\SystemConfig\SystemConfigService;
use Shopware\Storefront\Controller\ProductController;
use Shopware\Storefront\Page\Product\Configurator\ProductCombinationFinder;
use Shopware\Storefront\Page\Product\ProductPageLoadedHook;
use Shopware\Storefront\Page\Product\ProductPageLoader;
use Shopware\Storefront\Page\Product\QuickView\MinimalQuickViewPageLoader;
use Shopware\Storefront\Page\Product\Review\ProductReviewLoader;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

#[Route(defaults: ['_routeScope' => ['storefront']])]
class ExtendedProductController extends ProductController
{
    /** @psalm-suppress InternalMethod  */
    public function __construct(
        private ProductPageLoader $productPageLoader,
        private ProductCombinationFinder $productCombinationFinder,
        private AbstractFindProductVariantRoute $findVariantRoute,
        private MinimalQuickViewPageLoader $minimalQuickViewPageLoader,
        private AbstractProductReviewSaveRoute $productReviewSaveRoute,
        private SeoUrlPlaceholderHandlerInterface $seoUrlPlaceholderHandler,
        private ProductReviewLoader $productReviewLoader,
        private SystemConfigService $systemConfigService
    ) {
        parent::__construct(
            $productPageLoader,
            $productCombinationFinder,
            $findVariantRoute,
            $minimalQuickViewPageLoader,
            $productReviewSaveRoute,
            $seoUrlPlaceholderHandler,
            $productReviewLoader,
            $systemConfigService
        );
    }

    #[Route(
        '/navigation/{navigationId}',
        name: 'frontend.detaila.page',
        options: ['seo' => true],
        methods: ['GET']
    )]
    public function index(SalesChannelContext $context, Request $request): Response
    {
        $page = $this->productPageLoader->load($request, $context);
        $this->hook(new ProductPageLoadedHook($page, $context));
        /** @psalm-suppress InternalMethod  */
        $ratingSuccess = $request->get('success');
        /**
         * @deprecated tag:v6.5.0 - remove complete if statement, cms page id is always set
         *
         * Fallback layout for non-assigned product layout
         */
        if (!$page->getCmsPage()) {
            Feature::throwException('v6.5.0.0', 'Fallback will be removed because cms page is always set in subscriber.');

            return $this->renderStorefront('@Storefront/storefront/page/product-detail/index.html.twig', ['page' => $page, 'ratingSuccess' => $ratingSuccess]);
        }

        return $this->renderStorefront('@Storefront/storefront/page/content/product-detail.html.twig', ['page' => $page]);
    }
}
