<?php

declare(strict_types=1);

namespace LinkMobility\ShopwareSmsApiPlugin\Core\Content\Flow\Dispatching\Action;

use LinkMobility\ShopwareSmsApiPlugin\Core\Framework\Event\SmsApiAware;
use LinkMobility\ShopwareSmsApiPlugin\Service\SmsSenderInterface;
use Shopware\Core\Content\Flow\Dispatching\Action\FlowAction;
use Shopware\Core\Framework\Event\FlowEvent;

class SmsApiAction extends FlowAction
{
    public function __construct(
        private SmsSenderInterface $smsSender
    ) {
    }

    public static function getName(): string
    {
        return 'action.send.sms';
    }

    public static function getSubscribedEvents(): array
    {
        return [
            self::getName() => 'handle',
        ];
    }

    public function requirements(): array
    {
        return [SmsApiAware::class];
    }

    public function handle(FlowEvent $event): void
    {
        $config = $event->getConfig();

        /** @var SmsApiAware $baseEvent */
        $baseEvent = $event->getEvent();

        $order = $baseEvent->getOrder();
        $rawSms = $config['smsContent'];

        if ($config['notifyMe']) {
            $phoneNumber = $config['ownerPhoneNumber'];
            $this->smsSender->sendOrderStateChanged($order, $phoneNumber, $rawSms);

            return;
        }

        $addressPhoneNumber = $order->getAddresses()?->first()?->getPhoneNumber();

        /** @var array $customFields */
        $customFields = $order->getOrderCustomer()?->getCustomFields();

        if (null !== $addressPhoneNumber) {
            $phoneNumber = $addressPhoneNumber;
            $this->smsSender->sendOrderStateChanged($order, $phoneNumber, $rawSms);
        }
    }
}
