<?php

declare(strict_types=1);

namespace LinkMobility\ShopwareSmsApiPlugin\Factory;

use LinkMobility\ShopwareSmsApiPlugin\Model\SmsConfig;
use Shopware\Core\System\SystemConfig\SystemConfigService;

class SmsConfigFactory implements SmsConfigFactoryInterface
{
    public function __construct(private SystemConfigService $configService)
    {
    }

    public function createAbandonedCartConfig(): SmsConfig
    {
        $array = $this->configService->get('LinkMobilityShopwareSmsApiPlugin.smsapi');
        $config = new SmsConfig();

        $config->setActive($array['cartSms'] ?? false);
        $config->setMessage($array['cartSmsValue'] ?? '');
        $config->setDateModifier($array['cartSmsPassed'] ?? 0);

        return $config;
    }

    public function createBirthdayConfig(): SmsConfig
    {
        $array = $this->configService->get('LinkMobilityShopwareSmsApiPlugin.smsapi');
        $config = new SmsConfig();

        $config->setActive($array['birthdaySms'] ?? false);
        $config->setMessage($array['birthdaySmsValue'] ?? '');

        return $config;
    }

    public function createInactivityConfig(): SmsConfig
    {
        $array = $this->configService->get('LinkMobilityShopwareSmsApiPlugin.smsapi');
        $config = new SmsConfig();

        $config->setActive($array['inactivitySms'] ?? false);
        $config->setMessage($array['inactivitySmsValue'] ?? '');
        $config->setDateModifier($array['inactivitySmsDaysPassed'] ?? 0);

        return $config;
    }

    public function createRegistrationCelebrationConfig(): SmsConfig
    {
        $array = $this->configService->get('LinkMobilityShopwareSmsApiPlugin.smsapi');
        $config = new SmsConfig();

        $config->setMessage($array['registrationCelebrationSmsValue'] ?? '');
        $config->setActive($array['registrationCelebration'] ?? false);
        $config->setDateModifier($array['registrationCelebrationSmsDaysPassed'] ?? 0);

        return $config;
    }

    public function createRestockNotifierConfig(): SmsConfig
    {
        $array = $this->configService->get('LinkMobilityShopwareSmsApiPlugin.productAware');
        $config = new SmsConfig();

        $config->setMessage($array['restockNotifierValue'] ?? '');
        $config->setActive($array['restockNotifier'] ?? false);
        $config->setDateModifier($array['registrationCelebrationSmsDaysPassed'] ?? 0);

        return $config;
    }
}
