<?php

declare(strict_types=1);

namespace LinkMobility\ShopwareSmsApiPlugin\Service\ScheduledTask;

use LinkMobility\ShopwareSmsApiPlugin\Factory\SmsConfigFactoryInterface;
use LinkMobility\ShopwareSmsApiPlugin\Model\SmsConfig;
use LinkMobility\ShopwareSmsApiPlugin\Service\SmsSenderInterface;
use Shopware\Core\Checkout\Customer\CustomerEntity;
use Shopware\Core\Framework\Context;
use Shopware\Core\Framework\DataAbstractionLayer\EntityRepository;
use Shopware\Core\Framework\DataAbstractionLayer\EntityRepositoryInterface;
use Shopware\Core\Framework\DataAbstractionLayer\Search\Criteria;
use Shopware\Core\Framework\DataAbstractionLayer\Search\Filter\ContainsFilter;
use Shopware\Core\Framework\MessageQueue\ScheduledTask\ScheduledTaskHandler;

class BirthdayScheduledTaskHandler extends ScheduledTaskHandler
{
    public function __construct(
        EntityRepositoryInterface $scheduledTaskRepository,
        private SmsSenderInterface $smsSender,
        private EntityRepository $entityRepository,
        private SmsConfigFactoryInterface $smsConfigFactory
    ) {
        parent::__construct($scheduledTaskRepository);
    }

    public static function getHandledMessages(): iterable
    {
        return [BirthdaySmsScheduledTask::class];
    }

    public function run(): void
    {
        $smsConfig = $this->smsConfigFactory->createBirthdayConfig();
        if ($smsConfig->isActive()) {
            $this->handleBirthDay($smsConfig);
        }
    }

    private function handleBirthDay(SmsConfig $config): void
    {
        $todayDate = new \DateTime('now');
        /** @psalm-suppress InternalMethod */
        $context = Context::createDefaultContext();
        $criteria = new Criteria();
        $criteria->addAssociation('defaultBillingAddress');
        $criteria->addFilter(new ContainsFilter('birthday', $todayDate->format('m-d')));

        $customers = $this->entityRepository->search($criteria, $context)->getEntities();

        /** @var CustomerEntity $customer */
        foreach ($customers as $customer) {
            $customFields = $customer->getCustomFields();
            $phoneNumber = $customer->getDefaultBillingAddress()?->getPhoneNumber();

            $consent = $customFields['link_mobility_shopware_sms_api_plugin_consent'] ?? null;
            if ($consent &&
                null !== $phoneNumber
            ) {
                $this->smsSender->sendCustomerAware($customer, $phoneNumber, $config->getMessage());
            }
        }
    }
}
