<?php

declare(strict_types=1);

namespace LinkMobility\ShopwareSmsApiPlugin\Service\ScheduledTask;

use LinkMobility\ShopwareSmsApiPlugin\Factory\SmsConfigFactoryInterface;
use LinkMobility\ShopwareSmsApiPlugin\Model\SmsConfig;
use LinkMobility\ShopwareSmsApiPlugin\Service\SmsSenderInterface;
use Shopware\Core\Checkout\Customer\CustomerEntity;
use Shopware\Core\Framework\Context;
use Shopware\Core\Framework\DataAbstractionLayer\EntityRepository;
use Shopware\Core\Framework\DataAbstractionLayer\EntityRepositoryInterface;
use Shopware\Core\Framework\DataAbstractionLayer\Search\Criteria;
use Shopware\Core\Framework\DataAbstractionLayer\Search\Filter\ContainsFilter;
use Shopware\Core\Framework\MessageQueue\ScheduledTask\ScheduledTaskHandler;

class RegistrationCelebrationScheduledTaskHandler extends ScheduledTaskHandler
{
    public function __construct(
        EntityRepositoryInterface $scheduledTaskRepository,
        private SmsSenderInterface $smsSender,
        private EntityRepository $customerRepository,
        private SmsConfigFactoryInterface $smsConfigFactory
    ) {
        parent::__construct($scheduledTaskRepository);
    }

    public static function getHandledMessages(): iterable
    {
        return [RegistrationCelebrationScheduledTask::class];
    }

    public function run(): void
    {
        $smsConfig = $this->smsConfigFactory->createRegistrationCelebrationConfig();

        if ($smsConfig->isActive()) {
            $this->handleInactivity($smsConfig);
        }
    }

    private function handleInactivity(SmsConfig $config): void
    {
        $fixedDate = new \DateTime('now');
        if (0 !== $config->getDateModifier()) {
            $fixedDate->modify('-' . $config->getDateModifier() . ' day');
        }

        /** @psalm-suppress InternalMethod */
        $context = Context::createDefaultContext();
        $criteria = new Criteria();
        $criteria->addAssociation('defaultBillingAddress');
        $criteria->addFilter(new ContainsFilter('createdAt', $fixedDate->format('Y-m-d')));

        $customers = $this->customerRepository->search($criteria, $context)->getEntities();

        /** @var CustomerEntity $customer */
        foreach ($customers as $customer) {
            $customFields = $customer->getCustomFields();
            $consent = $customFields['link_mobility_shopware_sms_api_plugin_consent'] ?? null;
            $phoneNumber = $customer->getDefaultBillingAddress()?->getPhoneNumber();
            if (null !== $phoneNumber &&
                $consent) {
                $this->smsSender->sendCustomerAware($customer, $phoneNumber, $config->getMessage());
            }
        }
    }
}
